<?php
/**
 * Theme related functions.
 *
 * @package Alaya_framework
 * @subpackage Miao
 * @since 1.0
 */

$tmp_dir = get_template_directory();

// Set the theme's content width.
if ( ! isset( $content_width ) ) {
	$content_width = 1200;
}

if ( ! function_exists( 'alaya_theme_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support post thumbnails.
 */
function alaya_theme_setup() {

	/*
	 * Makes theme available for translation.
	 *
	 * Translations can be added to the /languages/ directory.
	 */
	 
	load_theme_textdomain( 'miao', get_template_directory().'/languages' ); 
	$locale = get_locale(); 
	$locale_file = get_template_directory_uri()."/languages/$locale.php"; 
	if ( is_readable($locale_file) ) require_once($locale_file);

	// This theme uses wp_nav_menu() in following locations.
	register_nav_menus( array(
		'primary_navi' => __( 'Primary Menu', 'miao' ),
		'footer_navi'  => __( 'Footer Menu', 'miao' ),
		'lang_navi'  => __( 'Language List', 'miao' )
	) );

	/**
	 * Enable support for Post Thumbnails on posts and pages
	 *
	 * @link https://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );
	
	/**
	 * Since WordPress 4.1, you can use add_theme_support to output the title tag in HTML.
	 */
	add_theme_support( "title-tag" );

	/**
	 * Add default posts and comments RSS feed links to head
	 */
	add_theme_support( 'automatic-feed-links' );
	
	/*Add post format support*/
    add_theme_support( 'post-formats', array( 'audio','video','gallery' ) );

	/*Remove the default gallery style*/
	add_filter( 'use_default_gallery_style', '__return_false' );
	
	/*Add shortcode support for widget text*/
	add_filter('widget_text', 'do_shortcode');
	
	/*Clear P tags in shortcodes*/
	function shortcode_empty_paragraph_fix($content){   
	    $array = array (
	        '<p>[' => '[', 
	        ']</p>' => ']', 
	        ']<br />' => ']'
	    );
	
	    $content = strtr($content, $array);
	    return $content;
	}
	add_filter('the_content', 'shortcode_empty_paragraph_fix');
	
	/*Add nofollow to Read More link for SEO*/
	function alaya_add_nofollow_to_link($link) {
		return str_replace('<a', '<a rel="nofollow"', $link);
	}
	add_filter('the_content_more_link','alaya_add_nofollow_to_link', 0);
	
	/*Declare WooCommerce support*/
	add_theme_support('woocommerce');

	/*Change excerpt more string*/
	function alaya_excerpt_more( $more ) {
		return '...';
	}
	add_filter( 'excerpt_more', 'alaya_excerpt_more' );

}
endif; // alaya_theme_setup
add_action( 'after_setup_theme', 'alaya_theme_setup' );

/**
* Register widget areas and widgets.
*
* @since 1.0
*/
function alaya_sidebar_init() {

	// Register widget areas
	register_sidebar(array(
		'name'          => __( 'Home Sidebar Widget Area', 'miao' ),
		'id'            => 'home_sidebar',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h6 class="widget_title">',
		'after_title'   => '</h6>',
		'description'   => __( 'Home Sidebar Widgets.', 'miao' )
	));
	
	register_sidebar(array(
		'name'          => __( 'Archive Sidebar Widget Area', 'miao' ),
		'id'            => 'archive_sidebar',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h6 class="widget_title">',
		'after_title'   => '</h6>',
		'description'   => __( 'Archive Sidebar Widgets.', 'miao' )
	));
	
	register_sidebar(array(
		'name'          => __( 'Post Sidebar Widget Area', 'miao' ),
		'id'            => 'post_sidebar',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h6 class="widget_title">',
		'after_title'   => '</h6>',
		'description'   => __( 'Post Sidebar Widgets.', 'miao' )
	));
	
	register_sidebar(array(
		'name'          => __( 'Shop Sidebar Widget Area', 'miao' ),
		'id'            => 'shop_sidebar',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h6 class="widget_title">',
		'after_title'   => '</h6>',
		'description'   => __( 'Shop Sidebar widgets.', 'miao' )
	));


   register_sidebar(array(
		'name'          => __( 'Forum Sidebar Widget Area', 'miao' ),
		'id'            => 'forum_sidebar',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h6 class="widget_title">',
		'after_title'   => '</h6>',
		'description'   => __( 'Forum Sidebar widgets.', 'miao' )
	));

	register_sidebar(array(
		'name'          => __( '#1 Bottom Widget Area', 'miao' ),
		'id'            => 'bottom_widget_1',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h6 class="widget_title">',
		'after_title'   => '</h6>',
		'description'   => __( '#1 Sitewide footer widgets.', 'miao' )
	));
	
	register_sidebar(array(
		'name'          => __( '#2 Bottom Widget Area', 'miao' ),
		'id'            => 'bottom_widget_2',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h6 class="widget_title">',
		'after_title'   => '</h6>',
		'description'   => __( '#2 Sitewide footer widgets.', 'miao' )
	));
	
	register_sidebar(array(
		'name'          => __( '#3 Bottom Widget Area', 'miao' ),
		'id'            => 'bottom_widget_3',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h6 class="widget_title">',
		'after_title'   => '</h6>',
		'description'   => __( '#3 Sitewide footer widgets.', 'miao' )
	));
	
	register_sidebar(array(
		'name'          => __( '#4 Bottom Widget Area', 'miao' ),
		'id'            => 'bottom_widget_4',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h6 class="widget_title">',
		'after_title'   => '</h6>',
		'description'   => __( '#4 Sitewide footer widgets.', 'miao' )
	));
}
add_action( 'widgets_init', 'alaya_sidebar_init' );

/**
 * Load CSS Files
*/
add_action('wp_enqueue_scripts', 'alaya_css');
function alaya_css(){

    //CSS Files
	wp_enqueue_style("style", get_stylesheet_uri(), false, null, "all");
	wp_enqueue_style("skeleton1200", get_template_directory_uri()."/assets/css/skeleton1200.css", false, null, "all");
	wp_enqueue_style("miao-reset", get_template_directory_uri()."/assets/css/reset.css", false, null, "all");
	wp_enqueue_style("miao-main", get_template_directory_uri()."/assets/css/main.css", false, null, "all");
	wp_enqueue_style("miao-javascript", get_template_directory_uri()."/assets/css/javascript.css", false, null, "all");
	wp_enqueue_style("font-awesome", get_template_directory_uri()."/assets/css/font-awesome/css/font-awesome.min.css", false, null, "all");
	wp_enqueue_style("miao-custom", get_template_directory_uri()."/custom.css", false, null, "all");
     
    //Responsive
    wp_enqueue_style("miao-responsive", get_template_directory_uri()."/assets/css/responsive.css", false, null, "all");
}

/*Load woocommerce Style*/
if ( class_exists( 'woocommerce')){
  add_action('wp_enqueue_scripts', 'alaya_woocommerce_style',11);
}
function alaya_woocommerce_style(){
    wp_dequeue_style( 'woocommerce_frontendstyles' );
	wp_enqueue_style( "woocommerce-miao", get_template_directory_uri()."/woocommerce/woocommerce-miao.css",false, null, "all");
    wp_enqueue_style( 'woocommerce_responsive_frontend', get_stylesheet_directory_uri()."/woocommerce/woocommerce-responsive.css" );
}

/*Load bbpress Style*/
if ( class_exists( 'bbPress')){
  add_action('wp_enqueue_scripts', 'alaya_bbpress_style',11);
  add_post_type_support('forum', array('thumbnail'));
}
function alaya_bbpress_style(){
	wp_enqueue_style( "bbpress-miao", get_template_directory_uri()."/bbpress/bbpress-miao.css",false, null, "all");
}

/**
 * Load Google Fonts
 * Hook: focux_scripts
 */
add_action( 'wp_enqueue_scripts', 'alaya_default_font' );
function alaya_default_font() {
    wp_enqueue_style( 'miao-default-fonts', alaya_font_styles(), array(), null );
}
function alaya_font_styles() {
    $fonts_url = '';
    $Sorts_Mill_Goudy = _x( 'on', 'Sorts Mill Goudy font: on or off', 'miao' );
    $open_sans = _x( 'on', 'Open Sans: on or off', 'miao' );
    $Roboto_Slab = _x( 'on', 'Roboto Slab: on or off', 'miao' );
    
    if ('off' !== $Sorts_Mill_Goudy || 'off' !== $open_sans || 'off' !== $Roboto_Slab) {
	    $font_families = array();
	 
	    if ( 'off' !== $open_sans ) {
	        $font_families[] = 'Open Sans:300italic,400italic,600italic,700italic,800italic,400,300,600,700,800';
	    }
	    
	    if ( 'off' !== $Sorts_Mill_Goudy ) {
	        $font_families[] = 'Sorts Mill Goudy:400,400italic';
	    }
	    
	    if ( 'off' !== $Roboto_Slab ) {
	        $font_families[] = 'Roboto Slab:400,700,300,100';
	    }
	    
	    $query_args = array(
            'family' => urlencode( implode( '|', $font_families ) ),
            'subset' => urlencode( 'latin,latin-ext,vietnamese,cyrillic-ext,cyrillic,greek,greek-ext' ),
        );
 
        $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
	}
    
    return esc_url_raw( $fonts_url );
}



/**
 * Load scripts
 */
add_action('wp_enqueue_scripts', 'alaya_scripts');
function alaya_scripts(){
    wp_enqueue_script( 'modernizr-custom', get_template_directory_uri() . '/assets/js/modernizr.custom.41385.js', array('jquery'), null, false );
	wp_enqueue_script( 'easing', get_template_directory_uri() . '/assets/js/jquery.easing.min.js', array('jquery'), null, false );
	wp_enqueue_script( 'animation-masonry', get_template_directory_uri() . '/assets/js/animation.masonry.js', array('jquery'), null, false );
	wp_enqueue_script( 'jflickrfeed', get_template_directory_uri() . '/assets/js/jflickrfeed.min.js', array('jquery'), null, false );
	wp_enqueue_script( 'colorbox', get_template_directory_uri() . '/assets/js/jquery.colorbox.js', array('jquery'), null, false );
	wp_enqueue_script( 'sticky', get_template_directory_uri() . '/assets/js/jquery.sticky.js', array('jquery'), null, true );
	wp_enqueue_script( 'superfish', get_template_directory_uri() . '/assets/js/jquery.superfish.js', array('jquery'), null, true );
	wp_enqueue_script( 'nicescroll', get_template_directory_uri() . '/assets/js/jquery.nicescroll.min.js', array('jquery'), null, true );
	wp_enqueue_script( 'justifiedGallery', get_template_directory_uri() . '/assets/js/jquery.justifiedGallery.min.js', array('jquery'), null, true );
	wp_enqueue_script( 'pushy', get_template_directory_uri() . '/assets/js/pushy.js', array('jquery'), null, true );
	wp_enqueue_script( 'flexslider', get_template_directory_uri() . '/assets/js/jquery.flexslider.js', array('jquery'), null, true );
	wp_enqueue_script( 'flexloader', get_template_directory_uri() . '/assets/js/jquery.flexloader.js', array('jquery'), null, true );
	wp_enqueue_script( 'hoverdelay', get_template_directory_uri() . '/assets/js/jquery.hoverdelay.js', array('jquery'),null,true);
	wp_enqueue_script( 'miao', get_template_directory_uri() . '/assets/js/jquery.miao.js', array('jquery', 'hoverIntent'), null, true );
}

add_action('wp_footer', 'alaya_js_arguments');
function alaya_js_arguments(){
   echo '<script type="text/javascript">
   var comment_title="'.__("COMMENT ON THIS POST","miao").'";
   </script>';
}


/**
 * Include theme partials: library, widgets, metaboxes and rest.
 */
include_once ( $tmp_dir . '/inc/init.php' );


/**
 * Include Framework Options
 */
require_once 'framework/bootstrap.php';
require_once 'inc/data_source.php';

/**
 * Create instance of Options
 */
$alaya_opt  = dirname( __FILE__ )."/inc/options.php";

$theme_options = new VP_Option(array(
	'is_dev_mode'           => false,                                  // dev mode, default to false
	'option_key'            => 'alaya_opt',                           // options key in db, required
	'page_slug'             => 'alaya_options',                           // options page slug, required
	'template'              => $alaya_opt,                              // template file path or array, required
	'menu_page'             => 'themes.php',                           // parent menu slug or supply `array` (can contains 'icon_url' & 'position') for top level menu
	'use_auto_group_naming' => true,                                   // default to true
	'use_util_menu'         => true,                                   // default to true, shows utility menu
	'minimum_role'          => 'edit_theme_options',                   // default to 'edit_theme_options'
	'layout'                => 'fixed',                                // fluid or fixed, default to fixed
	'page_title'            => __( 'Theme Options', 'miao' ), // page title
	'menu_label'            => __( 'Theme Options', 'miao' ), // menu label
));

function alaya_opt( $name ){
    return vp_option( "alaya_opt." . $name );
}

/**
 * MetaBox Options
 */
$alaya_post_format_metabox  = $tmp_dir . '/inc/metabox/post-format-field.php';
$alaya_contact_metabox  = $tmp_dir . '/inc/metabox/contact-field.php';
$alaya_custom_page_metabox  = $tmp_dir . '/inc/metabox/custom-page-field.php';

$post_format_field = new VP_Metabox($alaya_post_format_metabox);
$contact_field = new VP_Metabox($alaya_contact_metabox);
$custom_page_metabox = new VP_Metabox($alaya_custom_page_metabox);

if(alaya_opt('header_style')==1){
	$alaya_post_template_metabox  = $tmp_dir . '/inc/metabox/post-template-field.php';
	$post_template_field = new VP_Metabox($alaya_post_template_metabox);
}

/**
 * Template Functions	
 */
include_once ( $tmp_dir . '/tpl/template_func.php' );