<?php
/**
 * Forums List Widgets
 * @package Alaya Framework
 * @subpackage Miao
 * @since 1.0
 */
class BBP_Forums_Topic_Count_Widget extends WP_Widget {
 
    public function __construct() {
    $widget_ops = array( 'classname' => 'bbp_forums_topic_count_widget_options', 'description' => __( 'A list of categorized forums with their topic count' ,'miao') );
    parent::__construct( false, __( '(Miao) bbPress Forums','miao' ), $widget_ops );
    }
 
    public function widget( $args, $instance ) {
    extract( $args );
    $title = apply_filters( 'bbp_forum_widget_title', $instance['title'] );
 
    echo $before_widget;
 
    if ( ! empty( $title ) )
        echo $before_title . $title . $after_title;
    ?>
    <ul class="miao_forums_list">
        <?php
        wp_list_pages( array(
            'title_li' => '',
            'post_type' => bbp_get_forum_post_type(),
            'sort_column' => 'menu_order',
            'walker' => new Forum_List_Walker,
            'no_found_rows' => true,
        ) );
        ?>
    </ul>
    <?php
    echo $after_widget;
    }
 
    public function form( $instance ) {
    $title = empty( $instance['title'] ) ? '' : esc_attr( $instance['title'] );
    ?>
    <p>
        <label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php _e( 'Title:' ,'miao'); ?>
            <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title','miao' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
        </label>
    </p>
    <?php
    }
 
    public function update( $new_instance, $old_instance ) {
    $instance = $old_instance;
    $instance['title'] = strip_tags( $new_instance['title'] );
 
    return $instance;
    }
 
}

add_action( 'widgets_init', function() {
    register_widget( 'BBP_Forums_Topic_Count_Widget' );
} );

class Forum_List_Walker extends Walker {
    var $tree_type = 'page';
    var $db_fields = array (
        'parent' => 'post_parent',
        'id' => 'ID'
    );
 
    function start_lvl( &$output, $depth = 0, $args = array()) {
        $indent = str_repeat( "\t", $depth );
        $output .= "\n$indent<ul class='children'>\n";
    }
 
    function end_lvl( &$output, $depth = 0, $args = array()) {
        $indent = str_repeat( "\t", $depth );
        $output .= "$indent</ul>\n";
    }
 
    function start_el( &$output, $page, $depth=0, $args=array(), $id = 0 ) {
        $indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';
 
        extract( $args, EXTR_SKIP );
        $css_class = array();
        $has_children = forum_list_widget_has_children( $page->ID );
        if ( ! bbp_is_single_user() && $current_page = get_the_ID() ) {
            $_current_page = get_post( $current_page );
            if ( in_array( $page->ID, $_current_page->ancestors ) )
                $css_class[] = 'current_forum_ancestor';
            if ( $has_children )
                $css_class[] = 'forum_category';
            if ( $page->ID == $current_page )
                $css_class[] = 'current_forum_item';
            elseif ( $_current_page && $page->ID == $_current_page->post_parent )
                $css_class[] = 'current_forum_parent';
        } elseif ( $page->ID == get_option( 'page_for_posts' ) ) {
            $css_class[] = 'current_forum_parent';
        }
 
        $css_class = implode( ' ', $css_class );
        $topic_count = ( $has_children ) ? '' : '<span class="topic-count">' . bbp_get_forum_topic_count( $page->ID ) . '</span>';
        $forum_item = ( $has_children ) ? '<span class="forum_category_title">' . apply_filters( 'the_title', $page->post_title, $page->ID ) . '</span>' . $topic_count : '<a href="' . get_permalink( $page->ID ) . '">' . apply_filters( 'the_title', $page->post_title, $page->ID ) . $topic_count . '</a>';
 
        $output .= $indent . '<li class="' . $css_class . '">' . $forum_item;
    }
 
    function end_el( &$output, $page, $depth = 0, $args = array()) {
        $output .= "</li>\n";
    }
 
}

function forum_list_widget_has_children( $page_id ) {
    $children = get_pages( array(
        'child_of' => $page_id,
        'post_type' => bbp_get_forum_post_type(),
    ) );
    if ( $children )
        return true;
    else
        return false;
}
?>